@@ -8,8 +8,6 @@ This crate is a high level library using **MagickWand** (ImageMagick) for image
 Identify an image.
 
 ```rust,ignore
-extern crate image_convert;
-
 use image_convert::{ImageResource, InterlaceType, identify};
 
 let input = ImageResource::from_path("tests/data/P1060382.JPG");
@@ -27,8 +25,6 @@ assert_eq!(InterlaceType::NoInterlace, id.interlace);
 Convert an image to a PNG image and also resize it.
 
 ```rust,ignore
-extern crate image_convert;
-
 use std::path::Path;
 
 use image_convert::{ImageResource, PNGConfig, to_png};
@@ -58,11 +54,6 @@ pub extern crate magick_rust;
 #[macro_use]
 extern crate enum_ordinalize;
 
-extern crate ico;
-extern crate once_cell;
-extern crate regex;
-extern crate str_utils;
-
 #[cfg(feature = "none-background")]
 macro_rules! set_none_background {
     ($mw:expr) => {{
